@@ -272,7 +272,7 @@ impl<R: Resolver> Crawler<R> {
         update_tx: Sender<JobUpdate<JS, TS>>,
     ) -> PinnedTask
     {
-        TracingTask::new(span!(Level::INFO, url=job.url.as_str()), async move {
+        TracingTask::new(span!(Level::ERROR, url=%job.url), async move {
             let job = ResolvedJob::from(job);
 
             let scheduler = TaskScheduler::new(
@@ -347,7 +347,7 @@ impl<JS: JobStateValues, TS: TaskStateValues, R: Resolver> MultiCrawler<JS, TS,
     }
 
     pub fn go(self) -> PinnedTask<'static> {
-        TracingTask::new(span!(Level::INFO), async move {
+        TracingTask::new(span!(Level::ERROR), async move {
             let mut handles = vec![];
             for _ in 0..self.concurrency_profile.domain_concurrency {
                 let h = tokio::spawn({
