@@ -9,10 +9,10 @@ pub use crate::{
         Link, LinkTarget, Job, JobCtx, Task, HttpStatus, JobStatus, JobUpdate,
         select::predicate::Name,
         select::document::Document,
-        async_channel::unbounded as ch_unbounded,
-        async_channel::bounded as ch_bounded,
-        async_channel::Receiver as ChReceiver,
-        async_channel::Sender as ChSender,
+        flume::unbounded as ch_unbounded,
+        flume::bounded as ch_bounded,
+        flume::Receiver as ChReceiver,
+        flume::Sender as ChSender,
     },
     resolver::{
         AsyncHyperResolver,
