@@ -42,8 +42,7 @@ impl<JS: JobStateValues, TS: TaskStateValues> TaskScheduler<JS, TS> {
     fn schedule(&mut self, task: Arc<Task>) {
         self.pages_pending += 1;
 
-        //we use try_send as it's faster and channel is unbounded
-        let r = self.tasks_tx.try_send(task);
+        let r = self.tasks_tx.send(task);
         if r.is_err() {
             panic!("cannot send task to tasks_tx! should never ever happen!")
         }
@@ -52,6 +51,7 @@ impl<JS: JobStateValues, TS: TaskStateValues> TaskScheduler<JS, TS> {
     fn schedule_filter(&mut self, task: &mut Task) -> task_filters::Action {
         let action = if task.link.redirect > 0 { "[scheduling redirect]" } else { "[scheduling]" };
 
+        let _span = span!(Level::ERROR, task = %task).entered();
         for filter in &mut self.task_filters {
             match filter.accept(&mut self.job.ctx, self.task_seq_num, task) {
                 task_filters::Action::Accept => continue,
@@ -112,7 +112,7 @@ impl<JS: JobStateValues, TS: TaskStateValues> TaskScheduler<JS, TS> {
     pub(crate) fn go<'a>(mut self) -> Result<PinnedTask<'a, JobUpdate<JS, TS>>> {
         let mut root_task = Task::new_root(&self.job.url)?;
 
-        Ok(TracingTask::new(span!(Level::INFO), async move {
+        Ok(TracingTask::new(span!(Level::ERROR, url = %self.job.url), async move {
             trace!(
                 soft_timeout_ms = self.job.settings.job_soft_timeout.as_millis() as u32,
                 hard_timeout_ms = self.job.settings.job_hard_timeout.as_millis() as u32,
